What’s new in version 0.4.2
===========================
Version available since December 3, 2021

Bug fixed
---------
Energy
++++++

Units
*****

New functionalities
-------------------

Energy
++++++

Units
*****

Conversion Units
****************
- New SingleConversionUnit that can have any energy vector as input or output (but single input and single output)

Energy Nodes
************

General
+++++++

Model
*****

Utils
*****

Actors
++++++

Deprecated
----------
ElectricalToThermalConversionUnit now deprecated
Energy
++++++

Consumption Units
*****************

Production Units
****************

Actors
++++++

Documentation
-------------
- Changing the jpeg general class diagram into png to show it in the doc
- Updating the authors
- Providing the publications

Contributors
------------

Sacha Hodencq,
Mathieu Brugeron
